
# django-peeringdb

[![PyPI](https://img.shields.io/pypi/v/django_peeringdb.svg?maxAge=2592000)](https://pypi.python.org/pypi/django_peeringdb)
[![PyPI](https://img.shields.io/pypi/pyversions/django-peeringdb.svg)](https://pypi.python.org/pypi/django-peeringdb)
[![Tests](https://github.com/peeringdb/django-peeringdb/workflows/tests/badge.svg)](https://github.com/peeringdb/django-peeringdb/actions/workflows/tests.yml)
[![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/peeringdb/django-peeringdb)](https://lgtm.com/projects/g/peeringdb/django-peeringdb/alerts/)
[![Codecov](https://img.shields.io/codecov/c/github/peeringdb/django-peeringdb/master.svg?maxAge=2592000)](https://codecov.io/github/peeringdb/django-peeringdb)

Django models for PeeringDB

See the docs at http://peeringdb.github.io/django-peeringdb/

